Citation
============

If you use this work, please cite the following publications:

* `Web server <https://doi.org/10.1093/nar/gkt416>`_ :cite:`Margreitter2013`
* `Force-field parameters for GROMACS 45A3 and 54A7 <https://doi.org/10.1371/journal.pcbi.1003154>`_
  :cite:`Petrov2013`
* `Updated phosphate parameters for GROMACS 45A8 <https://doi.org/10.1002/jcc.24733>`_
  :cite:`Margreitter2017`

.. rubric:: REFERENCES

.. bibliography:: references.bib